#
# spec file for package rpmlint-mini
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           rpmlint-mini
Version:        1.10
Release:        lp151.5.3.1
Summary:        RPM file correctness checker
License:        GPL-2.0+
Group:          System/Packages
Url:            http://rpmlint.zarb.org/
Source:         desktop-file-utils-0.23.tar.xz
Source100:      rpmlint-deps.txt
Source101:      rpmlint.wrapper
Source102:      rpmlint-mini.config
Source103:      polkit-default-privs.config
Source104:      appdata_checker.config
Source1000:     rpmlint-mini.rpmlintrc
# need to fetch the file from there
BuildRequires:  checkbashisms
BuildRequires:  dash
BuildRequires:  glib2-devel
BuildRequires:  glib2-devel-static
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  polkit-default-privs
BuildRequires:  rpmlint
#!BuildIgnore:  rpmlint-mini
Requires:       cpio

%description
rpmlint is a tool to check common errors on RPM packages. Binary and
source packages can be checked.

%prep
%setup -q -n desktop-file-utils-0.23
[[ -r COPYING ]]

%build
%configure
pushd src
make %{?_smp_mflags} desktop-file-validate V=1 DESKTOP_FILE_UTILS_LIBS="%{_libdir}/libglib-2.0.a -lpthread -lrt"
popd

%install
# test if the rpmlint works at all
set +e
%{_bindir}/rpmlint rpmlint
test $? -gt 0 -a $? -lt 60 && exit 1
set -e
# okay, lets put it together
mkdir -p %{buildroot}/opt/testing/share/rpmlint
install -m 755 -D src/desktop-file-validate %{buildroot}/opt/testing/bin/desktop-file-validate
cp -a %{_bindir}/dash %{_bindir}/checkbashisms %{buildroot}/opt/testing/bin
mkdir -p %{buildroot}/opt/testing/%{_lib}
cp -a %{_libdir}/libedit.so.0* %{buildroot}/opt/testing/%{_lib}
cp -a %{_datadir}/rpmlint/*.py %{buildroot}/opt/testing/share/rpmlint
# install config files
install -d -m 755 %{buildroot}/opt/testing/share/rpmlint/mini
for i in %{_sysconfdir}/rpmlint/{pie,licenses}.config "%{SOURCE103}" "%{SOURCE104}"; do
  cp $i %{buildroot}/opt/testing/share/rpmlint/mini
done
install -m 644 -D %{_datadir}/rpmlint/config %{buildroot}/opt/testing/share/rpmlint/config
install -m 644 "%{SOURCE102}" %{buildroot}/opt/testing/share/rpmlint
# extra data
install -m 755 -d %{buildroot}/opt/testing/share/rpmlint/data
install -m 644 %{_sysconfdir}/polkit-default-privs.standard %{buildroot}/opt/testing/share/rpmlint/data
#
pushd %{_libdir}/python%{py3_ver}/
for f in $(<%{SOURCE100}); do
  find -path "*/$f" -exec install -D {} %{buildroot}/opt/testing/%{_lib}/python%{py3_ver}/{} \;
done
# ErlangCheck dependencies that are not under %_libdir but under /usr/lib :-(
cp -a %{python3_sitelib}/{construct,pybeam,six.py} %{buildroot}/opt/testing/%{_lib}/python%{py3_ver}/site-packages
install -D %{_bindir}/python3 %{buildroot}/opt/testing/bin/python3
cp -a %{_libdir}/libpython%{py3_ver}m.so.* %{buildroot}/opt/testing/%{_lib}
cp -a %{_bindir}/rpmlint %{buildroot}/opt/testing/share/rpmlint/rpmlint.py
pushd %{buildroot}/opt/testing/share/rpmlint
PYTHONOPTIMIZE=1 python3 -O -m compileall -b *.py
rm *.py
popd
pushd %{buildroot}/opt/testing/%{_lib}/python%{py3_ver}/
PYTHONOPTIMIZE=1 find -name \*.py -exec python3 -O -m compileall -b {} \; -delete
popd
find %{buildroot}/opt/testing/ -name __pycache__  -print -exec rm -Rf {} +
rm -rf %{buildroot}/{usr,etc}
rm -f %{buildroot}/opt/testing/bin/rpmlint
install -m 755 -D %{SOURCE101} %{buildroot}/opt/testing/bin/rpmlint
# hackatlon
%define my_requires %{_builddir}/%{?buildsubdir}/%{name}-requires
cat << EOF > %{my_requires}
cat - > file.list
%{__find_requires} < file.list > requires.list
%{__find_provides} < file.list > provides.list
while read i; do
    grep -F -v "\$i" requires.list > requires.list.new
    mv requires.list.new requires.list
done < provides.list
cat requires.list
rm -f requires.list provides.list file.list
EOF
chmod +x %{my_requires}
%define _use_internal_dependency_generator 0
%define __find_requires %{my_requires}
%define __find_provides %{nil}
# final run check to detect python dep changes
LD_LIBRARY_PATH=%{buildroot}/opt/testing/%{_lib}
PYTHONPATH=%{buildroot}/opt/testing/share/rpmlint
PYTHONHOME=%{buildroot}/opt/testing/
export PYTHONPATH LD_LIBRARY_PATH PYTHONHOME
%{buildroot}/opt/testing/bin/python3 -tt -u -O %{buildroot}/opt/testing/share/rpmlint/rpmlint.pyc  /.build.binaries/*.rpm 2>&1 || exit 1
echo ".. ok"

%files
/opt/testing
%doc COPYING

%changelog
* Mon Dec  4 2017 dimstar@opensuse.org
- rpmlint-deps.txt: Follow changes from rpm and copy _rpm*.so
  instead of _rpm.so (the name is newly extended with .cpython).
* Wed Nov  1 2017 dmueller@suse.com
- set locale to C.utf8 to avoid non-ascii warnings
* Tue Oct 24 2017 jengelh@inai.de
- Update descriptions. Use better-performing find invocations.
* Mon Oct 16 2017 dmueller@suse.com
- don't include a copy of libmagic (bsc#976406)
* Thu Oct 12 2017 stefan.bruens@rwth-aachen.de
- Use wildcard for sysconfigdata architecture in rpmlint-deps.txt
- Use wildcard for abi in rpmlint-deps.txt, e.g. armv7hl is gnueabihf
* Tue Oct 10 2017 dmueller@suse.com
- also import ElementTree
- include pybeam also for lib64 architectures
* Thu Sep 28 2017 dmueller@suse.com
- rebuild against rpmlint 1.10
  drops: rpmlint-deps.patch
- Switch to Python 3.x
* Fri May 26 2017 matwey.kornilov@gmail.com
- Add rpmlint-deps.patch:
  Revert 'Adapt rpmlint-deps.txt for python-construct >= 2.8'
  for Leap 42.x
* Wed Feb  1 2017 meissner@suse.com
- buildignore ourselves to allow better bootstrapping.
* Wed Jan 18 2017 matwey.kornilov@gmail.com
- Adapt rpmlint-deps.txt for python-construct >= 2.8
* Fri Dec  9 2016 dimstar@opensuse.org
- Configure appdata_checker: pass --nonet in plus: as OBS has no
  internet access, every appdata file containing screenshots would
  be marked as 'failed' otherwise.
* Fri Oct 28 2016 dmueller@suse.com
- update desktop-file-utils to 0.23:
  + Accept version 1.1 desktop files.
  + Add Cinnamon, EDE and LXQt to the list of registered desktop
    environments (fdo#73497, fdo#56353, fdo#79561).
  + Allow multipart/related MIME type; it's used for MHTML
    (fdo#93376).
  + Ensure DBusActivatable filenames conform to reverse-DNS
    notation (fdo#66904).
  + Downgrade trailing semicolons to optional (fdo#76902).
  + Fix buffer over-read (fdo#94303).
* Wed Apr 20 2016 werner@suse.de
- Also copy magic and magic.mgc to /opt/testing to have the
  correct magic files for the used libmagic around.
  Use the environment variable MAGIC to hel the wrapper to
  to find the magic file for its libmagic (boo#976406)
* Mon Feb 22 2016 dmueller@suse.com
- raise version to 1.8
* Mon Apr 20 2015 lnussel@suse.de
- add lib-dynload/unicodedata.so required by rpmlint 1.6
* Sat Apr 26 2014 matwey.kornilov@gmail.com
- package dependencies of ErlangCheck.py:
  - python-pybeam
  - python-construct
  - python-six
  note, that ErlangCheck.py is not enabled by default
* Thu Oct  3 2013 dmueller@suse.com
- repackage libedit0 dependency of dash
* Wed Oct  2 2013 lnussel@suse.de
- dash is in /usr/bin now
* Tue Sep 24 2013 dmueller@suse.com
- no longer install rpmgroups.config
* Mon Sep  2 2013 dmueller@suse.com
- update to desktop-file-validate 0.22:
  - add DBusActivatable key to allowed keys
  - warn about OnlyShowIn in Action groups
  - allow validating multiple desktop files
  - improve help output
  - update man page
* Fri Jun 28 2013 dmueller@suse.com
- update to desktop-file-validate 0.21:
  - update to current version of menu specification (Vincent):
  - only print hint if no main category is present, not an error
  - make Science a main category
  - add new registered categories: Adult, Feed, Humanities, Maps,
    Shooter, Spirituality, XFCE
  - update related categories
  - add TDE to list of registered OnlyShowIn
  - accept and validate GNOME3/GSettings for AutostartCondition (Vincent)
  - output hint if more than one main category is present (Vincent)
  - output hint about suggested related categories (Vincent)
* Wed Jun 26 2013 dmueller@suse.com
- fix build against python 2.7.5
* Wed Jan  2 2013 dmueller@suse.com
- bump version to 1.4
* Sun Oct 28 2012 coolo@suse.com
- fix build by passing rpmlint :)
* Sun Oct 28 2012 coolo@suse.com
- let it require cpio - the same as with rpmlint
* Wed Sep 12 2012 dmueller@suse.com
- update to desktop-file-validate 0.20 (bnc#779850):
  - add MATE and Razor to list of registered environments (Vincent)
  - validate Desktop Actions (Giovanni Campagna, Vincent)
* Fri Feb 24 2012 giecrilj@stegny.2a.pl
- add documentation
* Wed Dec 21 2011 dmueller@suse.de
- update desktop-file-validate to 0.19:
  - add Unity to list of registered environments
  - deal with various zz-application/zz-winassoc-XXX mime types
  - mark all zz-application/* MIME types as aliases
  - add support for updated Keywords key
  - accept x-scheme-handler/* mime types
* Tue Nov 29 2011 lnussel@suse.de
- install licenses.config
* Mon Oct 24 2011 dmueller@suse.de
- add the new abuild build path to the search dir list
* Thu Aug 18 2011 dmueller@suse.de
- bump version to 1.3 (matching rpmlint update)
* Fri Jul  8 2011 dmueller@novell.com
- fix magic detection after the file update to 5.07
* Fri May 20 2011 dmueller@suse.de
- bump version to 1.2 (matching rpmlint update)
* Wed May 11 2011 lnussel@suse.de
- include pie.config
* Tue Apr 19 2011 lnussel@suse.de
- allow adding configs via RPMLINT_MINI_CONFIG
* Mon Apr 18 2011 lnussel@suse.de
- add missing deps
* Fri Apr 15 2011 dmueller@suse.de
- bump version to 1.1 (matching rpmlint update)
* Thu Mar 10 2011 lnussel@suse.de
- rlwarn was renamed to warn
* Sun Nov 21 2010 coolo@novell.com
- fix lib requirements of libglib
* Thu Nov 11 2010 dmueller@suse.de
- bump version to 1.0 (match rpmlint update)
* Mon Sep 27 2010 dmueller@suse.de
- bump version to 0.99 (match rpmlint update)
- buildrequire glib2-devel-static (new package split)
* Mon Sep 20 2010 dmueller@suse.de
- fix build against autoconf 2.67
  + update to desktop-file-utils 0.17:
  - accept chemical/* mime types as valid types
  - make icon names with an extension for Icon key a non-fatal
    error
  - check that a main category is included in the Categories
  - check that categories required by another one are present
  - do not always show warnings about KDE specific uses
  - check that the Comment does not look like the Name and the
    GenericName
  - display error about multiple keys with the same name earlier
  - improve MIME type check to make sure that the MIME types are
    valid
  - add LXDE in the list of registered OnlyShowIn values
  - add "warning" to error strings to make them easily greppable
  - handle AutostartCondition key, as proposed for the autostart
    specification and used in GNOME
  - accept empty Categories key as valid
  - make new errors non-fatal to give some time to maintainers to
    fix their .desktop file after a release of desktop-file-utils
  - plug leak
  - code cleanups
* Sun Sep 12 2010 dmueller@suse.de
- fix build against python 2.7
* Tue Aug  3 2010 dmueller@suse.de
- add string_escape to dependencies, needed by checkbashisms
* Tue Jul 20 2010 guido+opensuse.org@berhoerster.name
- include dash and checkbashisms needed by BashismsCheck
* Mon Mar 29 2010 dmueller@suse.de
- update dependency list for rpmlint 0.95 / rpm 4.8.0
* Fri Feb 26 2010 lnussel@suse.de
- fix polkit check
* Thu Feb 25 2010 lnussel@suse.de
- configure CheckPolkitPrivs
* Thu Jan 21 2010 lnussel@suse.de
- remove error prone package-rpmlintrc.diff. Instead have rpmlint
  execute a file via standard means which in turn reads custom
  configs
* Wed Jan 13 2010 lnussel@suse.de
- add rpmgroups.config
* Mon Sep 28 2009 lnussel@suse.de
- include python-magic to fix e.g. the 'no-binary' check (bnc#539042)
* Wed Sep 16 2009 mrueckert@suse.de
- fix build with rpmlint 0.90
* Mon Aug 24 2009 lnussel@suse.de
- fix build with rpmlint 0.87
* Fri Jan 23 2009 lnussel@suse.de
- include StringIO.pyo, needed by xml module used by the dbus policy
  check to print useful errors
* Thu Dec 11 2008 lnussel@suse.de
- add python-xml parts needed for PolicyKit checks
* Sat Sep 27 2008 adrian@suse.de
- fix dependencies of python again (bnc#430381)
- add self check to avoid breakage in future
* Mon Sep  8 2008 ro@suse.de
- next try to get a working rpmlint again
* Mon Sep  8 2008 dmueller@suse.de
- fix build again
* Thu Aug  7 2008 dmueller@suse.de
- fix build for python 2.6
* Thu Jul 24 2008 dmueller@suse.de
- support even OBS style of building
* Mon Jun 30 2008 schwab@suse.de
- Fix syntax error.
* Fri Jun 27 2008 dmueller@suse.de
- ignore warnings in the test package
* Mon Mar 10 2008 dmueller@suse.de
- update desktop-file-validate to 0.14
  * for changelog, see desktop-file-utils package
* Wed Feb 13 2008 dmueller@suse.de
- update to (also) build rpmlint 0.82
* Thu Nov 22 2007 dmueller@suse.de
- add missing utf8 module (#343642)
* Mon Oct 29 2007 dmueller@suse.de
- update to (also) build rpmlint 0.81
- update desktop-file-validate to 0.14
* Thu Jun 21 2007 dmueller@suse.de
- refresh patches
* Thu Jun  7 2007 dmueller@suse.de
- update desktop-file-validate to 0.13
- fix build for lib64 archs
* Wed Jun  6 2007 dmueller@suse.de
- add static copy of desktop-file-validate to fix
  the rpmlint check for desktop files
* Mon Jun  4 2007 dmueller@suse.de
- remove source files to reduce size
- read $RPM_SOURCE_DIR/%%{name}-%%{version}-rpmlintrc as well
* Thu May 24 2007 dmueller@suse.de
- read $RPM_SOURCE_DIR/rpmlintrc as well to allow
  package specific overrides
* Tue May 15 2007 dmueller@suse.de
- Initial package
